Think harder to complete these tasks:
1. Review artifacts/refer/claude-code-best-practices.md to learn and apply Claude Code Best Practices.
2. Review the current state of the project if any code and documentation already exists.
3. Now create or update CLAUDE.md files for project root as well as key code folders of the project if these exist.
